/* cmd_neonfun.c - NeonServ v5.6
 * Copyright (C) 2011-2012  Philipp Kreil (pk910)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program. If not, see <http://www.gnu.org/licenses/>. 
 */
#include "../module.h"

#include "cmd_neonfun.h"
#include "../../modcmd.h"
#include "../../lang.h"
#include "../../ConfigParser.h"

static const struct default_language_entry msgtab[] = {
    {"NF_UNO_ALREADY_RUNNING", "There is already a UNO game running in %s."}, /* {ARGS: "#channel"} */
    {"NF_UNO_ALREADY_JOINED", "You have already joined this UNO game."},
    {"NF_UNO_USER_JOINED", "$b%s$b has joined the game."}, /* {ARGS: "TestUser"} */
    {"NF_UNO_CREATED", "$b%s$b started an UNO game. Type $b+uno$b to join the game."}, /* {ARGS: "TestUser"} */
    {"NF_UNO_ERROR", "UNO program error. Please contact a bot administrator. (ErrCode: %d)"}, /* {ARGS: 0} */
    {"NF_UNO_START", "GAME START"},
    {"NF_UNO_USER_HURRY_UP", "$b%s$b, it's your turn!"}, /* {ARGS: "TestUser"} */
    {"NF_UNO_USER_TOOK_CARD", "$b%s$b took another card."}, /* {ARGS: "TestUser"} */
    {"NF_UNO_USER_TOOK_CARDS", "$b%s$b took $b%d$b cards."}, /* {ARGS: "TestUser", 4} */
    {"NF_UNO_YOUR_CARDS", "Your cards: %s"}, /* {ARGS: "[+2] [+4] [R5] ..."} */
    {"NF_UNO_TOP_CARD", "upper card: %s"}, /* {ARGS: "[+4]"} */
    {"NF_UNO_NOT_YOUR_TURN", "Wait your turn!"},
    {"NF_UNO_UNKNOWN_CARD", "Unknown card [%s]."}, /* {ARGS: "xy"} */
    {"NF_UNO_CARD_NOT_IN_DECK", "You don't have this card."},
    {"NF_UNO_CARD_YELLOW", "yellow"},
    {"NF_UNO_CARD_BLUE", "blue"},
    {"NF_UNO_CARD_RED", "red"},
    {"NF_UNO_CARD_GREEN", "green"},
    {"NF_UNO_DEFINE_COLOR", "Please define the color you want to set as a parameter to the command (eg. $b+unoplay +4 RED$b)"},
    {"NF_UNO_CARD_NOT_POSSIBLE", "You can't play this card."},
    {"NF_UNO_ONE_CARD", "$b%s$b has only one card! $k4U$k$k9N$k$k12O$k"}, /* {ARGS: "TestUser"} */
    {"NF_UNO_USER_WIN", "$b%s$b has 0 cards! $k4U$k$k9N$k$k12O$k $k4U$k$k9N$k$k12O$k!!!"}, /* {ARGS: "TestUser"} */
    {"NF_UNO_TIMEOUT", "game stopped (no more active players)."},
    {"NF_UNO_USER_SKIP", "skipped $b%s$b."}, /* {ARGS: "TestUser"} */
    {"NF_UNO_GAME_FINISHED", "The UNO Game has been finished!"},
    {"NF_UNO_ADD_CARD", "$b%s$b has to take up %d cards. There is still the possibility that he/she has another card of this type...?"},
    {"NF_UNO_RANK", "Rank"},
    {"NF_UNO_NAME", "Name"},
    {"NF_UNO_WON_GAMES", "Won Games"},
    {"NF_UNO_TOTAL_WON_GAMES", "Total won Games"},
    {"NF_UNO_LESS_PLAYERS", "There are not enough players to start the game."},
    
    {"NF_4WINS_NOT_YOUR_TURN", "Wait your turn!"},
    {"NF_4WINS_INVALID_COLUMN", "invalid column!"},
    {"NF_4WINS_COLUMN_FULL", "This column is full!"},
    {"NF_4WINS_USER_HURRY_UP", "$b%s$b, it's your turn! To put a stone into a column use: 4stone <colomn>"}, /* {ARGS: "TestUser"} */
    {"NF_4WINS_USER_WON", "$b%s$b won the game!"}, /* {ARGS: "TestUser"} */
    {"NF_4WINS_ENTER_OPPONENT", "Please enter the nick of the opponent you want to play against as a parameter of 4wins (eg. $b4wins TestUser$b)"},
    {"NF_4WINS_OPPONENT_NOT_IN_CHAN", "$b%s$b needs to be in this channel to start a game against him/her."}, /* {ARGS: "TestUser"} */
    {"NF_4WINS_DRAW", "Nobody has won this game."},
    {"NF_4WINS_REQUEST", "$b%s$b wants to play a game against you. use $b4wins$b to start the game."}, /* {ARGS: "TestUser"} */
    {"NF_4WINS_REQUESTED", "waiting for $b%s$b accepting the game..."}, /* {ARGS: "TestUser"} */
    {"NF_4WINS_START", "%s accepted the challenge! game starts:"}, /* {ARGS: "TestUser"} */
    {"NF_4WINS_APPEND_PLAYER", "Please append the nick of a player playing the game you want to view. (eg. $b4view TestUser$b)"},
    {"NF_4WINS_NO_GAME_FOUND", "Couldn't find a game with this user in this channel."},
    {"NF_4WINS_VIEWING_ANOTHER_GAME", "You are already viewing another game."},
    {"NF_4WINS_VIEWING_GAME", "You are now viewing the game."},
    {"NF_4WINS_GAME_CLOSED", "Game aborted."},
    {"NF_4WINS_TIMEOUT", "Game aborted (timeout)."},
    {"NF_4WINS_SELF", "You may not play against yourself."},
    
    {"NF_BJ_ALREADY_RUNNING", "There is already a BlackJack game running in %s."}, /* {ARGS: "#channel"} */
    {"NF_BJ_ALREADY_JOINED", "You have already joined this BlackJack game."},
    {"NF_BJ_USER_JOINED", "$b%s$b has joined the game."}, /* {ARGS: "TestUser"} */
    {"NF_BJ_CREATED", "$b%s$b started a BlackJack game. Type $b+bj$b to join the game."}, /* {ARGS: "TestUser"} */
    {"NF_BJ_ERROR", "BlackJack program error. Please contact a bot administrator. (ErrCode: %d)"}, /* {ARGS: 0} */
    {"NF_BJ_NOT_YOUR_TURN", "Wait your turn!"},
    {"NF_BJ_START", "GAME START"},
    {"NF_BJ_USER_HURRY_UP", "$b%s$b, it's your turn! You can take a card with $bbjtake$b or stop playing with $bbjenough$b"}, /* {ARGS: "TestUser"} */
    {"NF_BJ_TAKE", "You took another card: %s (%d points)."}, /* {ARGS: "[&#9824;A]", 11} */
    {"NF_BJ_YOUR_CARDS", "You have %d points! Your cards: %s"}, /* {ARGS: 18, "[&#9824;A] [&#9827;7] ..."} */
    {"NF_BJ_LESS_PLAYERS", "There are not enough players to start the game."},
    {"NF_BJ_USER_TIMEOUT", "It seems that %s doesn't want another card... (Timeout)"}, /* {ARGS: "TestUser"} */
    {"NF_BJ_POINTS_EXCEEDED", "You have more than 21 points... please use $bbjenough$b to finish."},
    {"NF_BJ_GAME_FINISHED", "Game Finished! Showdown:"},
    {"NF_BJ_RANK", "Rank"},
    {"NF_BJ_NAME", "Name"},
    {"NF_BJ_POINTS", "Points"},
    {"NF_BJ_CARDS", "Cards"},
    
    {NULL, NULL}
};

void register_commands() {
    //NeonFun Commands
    register_default_language_table(msgtab);
    register_command_alias(5, "NeonFun");
    
    #define USER_COMMAND(NAME,FUNCTION,PARAMCOUNT,PRIVS,FLAGS) register_command(5, NAME, module_id, FUNCTION, PARAMCOUNT, PRIVS, 0, FLAGS)
    //           NAME            FUNCTION              PARAMS  PRIVS     FLAGS
    USER_COMMAND("uno",          neonfun_cmd_uno,      0,      NULL,     CMDFLAG_REQUIRE_CHAN | CMDFLAG_REGISTERED_CHAN);
    USER_COMMAND("unotake",      neonfun_cmd_unotake,  0,      NULL,     CMDFLAG_REQUIRE_CHAN | CMDFLAG_REGISTERED_CHAN);
    USER_COMMAND("unoplay",      neonfun_cmd_unoplay,  1,      NULL,     CMDFLAG_REQUIRE_CHAN | CMDFLAG_REGISTERED_CHAN);
    
    USER_COMMAND("4wins",        neonfun_cmd_4wins,    0,      NULL,     CMDFLAG_REQUIRE_CHAN | CMDFLAG_REGISTERED_CHAN);
    USER_COMMAND("4stone",       neonfun_cmd_4stone,   1,      NULL,     CMDFLAG_REQUIRE_CHAN | CMDFLAG_REGISTERED_CHAN);
    USER_COMMAND("4view",        neonfun_cmd_4view,    0,      NULL,     CMDFLAG_REQUIRE_CHAN | CMDFLAG_REGISTERED_CHAN);
    
    USER_COMMAND("blackjack",    neonfun_cmd_blackjack,0,      NULL,     CMDFLAG_REQUIRE_CHAN | CMDFLAG_REGISTERED_CHAN);
    USER_COMMAND("bjtake",       neonfun_cmd_bjtake,   0,      NULL,     CMDFLAG_REQUIRE_CHAN | CMDFLAG_REGISTERED_CHAN);
    USER_COMMAND("bjenough",     neonfun_cmd_bjenough, 0,      NULL,     CMDFLAG_REQUIRE_CHAN | CMDFLAG_REGISTERED_CHAN);
    
    #undef USER_COMMAND
    
}


