/* bot_NeonKick.c - NeonServ v5.6
 * Copyright (C) 2011-2012  Philipp Kreil (pk910)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program. If not, see <http://www.gnu.org/licenses/>. 
 */
#include "../module.h"
#include "../botid.h"

#include "bot_NeonKick.h"
#include "../../modcmd.h"
#include "../../IRCParser.h"
#include "../../IRCEvents.h"
#include "../../UserNode.h"
#include "../../ChanNode.h"
#include "../../ChanUser.h"
#include "../../ModeNode.h"
#include "../../BanNode.h"
#include "../../ClientSocket.h"
#include "../../mysqlConn.h"
#include "../../lang.h"
#include "../../HandleInfoHandler.h"
#include "../../WHOHandler.h"
#include "../../DBHelper.h"
#include "../../tools.h"
#include "../../timeq.h"
#include "../../version.h"
#include "../../EventLogger.h"
#include "../../bots.h"

#define BOTID NEONKICK_BOTID
#define BOTALIAS "NeonKick"

static void neonkick_bot_ready(struct ClientSocket *client) {
    if(client->botid != BOTID)
        return;
    MYSQL_RES *res;
    MYSQL_ROW row;
    
    printf_mysql_query("SELECT `automodes`, `oper_user`, `oper_pass` FROM `bots` WHERE `id` = '%d'", client->clientid);
    res = mysql_use();
    if ((row = mysql_fetch_row(res)) != NULL) {
        if(row[1] && row[2]) {
            putsock(client, "OPER %s %s", row[1], row[2]);
        }
        putsock(client, "MODE %s +%s", client->user->nick, row[0]);
    }
    
    printf_mysql_query("SELECT `channel_name`, `channel_key` FROM `bot_channels` LEFT JOIN `channels` ON `chanid` = `channel_id` WHERE `botid` = '%d' AND `suspended` = '0'", client->clientid);
    res = mysql_use();
    
    while ((row = mysql_fetch_row(res)) != NULL) {
        putsock(client, "JOIN %s %s", row[0], row[1]);
    }
}

static void neonkick_trigger_callback(int clientid, struct ChanNode *chan, char *trigger) {
    //this bot doesn't have a trigger
    strcpy(trigger, "");
}

static void start_bots(int type) {
    struct ClientSocket *client;
    MYSQL_RES *res, *res2;
    MYSQL_ROW row;
    
    if(type == MODSTATE_STARTSTOP) {
        printf_mysql_query("SELECT `nick`, `ident`, `realname`, `server`, `port`, `pass`, `textbot`, `id`, `queue`, `ssl`, `bind`, `secret` FROM `bots` WHERE `botclass` = '%d' AND `active` = '1'", BOTID);
        res = mysql_use();
        
        while ((row = mysql_fetch_row(res)) != NULL) {
            client = create_socket(row[3], atoi(row[4]), row[10], row[5], row[0], row[1], row[2]);
            client->flags |= (strcmp(row[6], "0") ? SOCKET_FLAG_PREFERRED : 0);
            client->flags |= (strcmp(row[8], "0") ? SOCKET_FLAG_USE_QUEUE : 0);
            client->flags |= (strcmp(row[9], "0") ? SOCKET_FLAG_SSL : 0);
            client->flags |= (strcmp(row[11], "0") ? SOCKET_FLAG_SECRET_BOT : 0);
            client->flags |= SOCKET_FLAG_SILENT;
            client->botid = BOTID;
            client->clientid = atoi(row[7]);
            connect_socket(client);
        }
    }
    
    printf_mysql_query("SELECT `command`, `function`, `parameters`, `global_access`, `chan_access`, `flags` FROM `bot_binds` WHERE `botclass` = '%d'", BOTID);
    res2 = mysql_use();
    while ((row = mysql_fetch_row(res2)) != NULL) {
        if(bind_cmd_to_command(BOTID, row[0], row[1])) {
            if(row[2] && strcmp(row[2], "")) {
                bind_set_parameters(BOTID, row[0], row[2]);
            }
            if(row[3]) {
                bind_set_global_access(BOTID, row[0], atoi(row[3]));
            }
            if(row[4]) {
                bind_set_channel_access(BOTID, row[0], row[4]);
            }
            if(strcmp(row[5], "0"))
                bind_set_bind_flags(BOTID, row[0], atoi(row[5]));
        }
    }
    bind_unbound_required_functions(BOTID);
}

static void neonkick_event_invite(struct ClientSocket *client, struct UserNode *user, char *channel) {
	if(client->botid != BOTID)
		return;
    MYSQL_RES *res;
    MYSQL_ROW row;
    printf_mysql_query("SELECT `botid`, `bot_channels`.`id`, `suspended` FROM `bot_channels` LEFT JOIN `bots` ON `bot_channels`.`botid` = `bots`.`id` LEFT JOIN `channels` ON `chanid` = `channel_id` WHERE `channel_name` = '%s' AND `botclass` = '%d'", escape_string(channel), client->botid);
    res = mysql_use();
    if ((row = mysql_fetch_row(res)) == NULL) {
        reply(client, user, "NS_INVITE_FAIL", channel, client->user->nick);
        return;
    }
    if(!strcmp(row[2], "1")) {
        return;
    }
    int botid = atoi(row[0]);
    struct ClientSocket *bot;
    for(bot = getBots(SOCKET_FLAG_READY, NULL); bot; bot = getBots(SOCKET_FLAG_READY, bot)) {
        if(bot->clientid == botid)
            break;
    }
    if(bot) {
        struct ChanNode *chan = getChanByName(channel);
        if(!(chan && isUserOnChan(bot->user, chan)))
            putsock(bot, "JOIN %s", channel);
    }
}

static char* getSetting(struct UserNode *user, struct ChanNode *chan, const char *setting) {
    char *uname = "";
    int cid = 0;
    MYSQL_RES *res;
    MYSQL_ROW row;
    if(user) {
        uname = ((user->flags & USERFLAG_ISAUTHED) ? user->auth : "*");
    }
    if(chan) {
        loadChannelSettings(chan);
        if(chan->flags & CHANFLAG_CHAN_REGISTERED)
            cid = chan->channel_id;
    }
    printf_mysql_query("SELECT `value` FROM `fundata` WHERE `user` = '%s' AND `cid` = '%d' AND `name` = '%s'", escape_string(uname), cid, escape_string(setting));
    res = mysql_use();
    if ((row = mysql_fetch_row(res)) != NULL) {
        return row[0];
    } else
        return NULL;
}

static void setSetting(struct UserNode *user, struct ChanNode *chan, const char *setting, const char *value) {
    char *uname = "";
    int cid = 0;
    MYSQL_RES *res;
    MYSQL_ROW row;
    if(user) {
        uname = ((user->flags & USERFLAG_ISAUTHED) ? user->auth : "*");
    }
    if(chan) {
        loadChannelSettings(chan);
        if(chan->flags & CHANFLAG_CHAN_REGISTERED)
            cid = chan->channel_id;
    }
    printf_mysql_query("SELECT `id`, `value` FROM `fundata` WHERE `user` = '%s' AND `cid` = '%d' AND `name` = '%s'", escape_string(uname), cid, escape_string(setting));
    res = mysql_use();
    if ((row = mysql_fetch_row(res)) != NULL) {
        if(strcmp(row[1], value))
            printf_mysql_query("UPDATE `fundata` SET `value` = '%s' WHERE `id` = '%s'", escape_string(value), row[0]);
    } else
        printf_mysql_query("INSERT INTO `fundata` (`user`, `cid`, `name`, `value`) VALUES ('%s', '%d', '%s', '%s')", escape_string(uname), cid, escape_string(setting), escape_string(value));
}

#include "event_neonkick_join.c"

void init_NeonKick(int type) {
    set_bot_alias(BOTID, BOTALIAS);
    start_bots(type);
    
    if(type == MODSTATE_REBIND) return;
    
    //register events
    bind_bot_ready(neonkick_bot_ready, module_id);
	bind_invite(neonkick_event_invite, module_id);
    bind_join(neonkick_event_join, module_id);
    
    set_trigger_callback(BOTID, module_id, neonkick_trigger_callback);
}

void free_NeonKick(int type) {
    unbind_allcmd(BOTID);
    if(type == MODSTATE_STARTSTOP) {
        //disconnect all our bots
        struct ClientSocket *client;
        for(client = getBots(0, NULL); client; client = getBots(0, client)) {
            if(client->botid == BOTID) {
                unbind_botwise_allcmd(0, client->clientid);
                close_socket(client);
                break;
            }
        }
    }
}

#undef BOTID
#undef BOTALIAS
